API Reference
=============

This section provides detailed documentation of pyngb's API.

Main Functions
--------------

.. automodule:: pyngb
   :members: read_ngb

Core Modules
------------

Binary Parser
~~~~~~~~~~~~~

.. automodule:: pyngb.binary.parser
   :members:

Binary Handlers
~~~~~~~~~~~~~~~

.. automodule:: pyngb.binary.handlers
   :members:

Core Parser
~~~~~~~~~~~

.. automodule:: pyngb.core.parser
   :members:

Extractors
~~~~~~~~~~

.. automodule:: pyngb.extractors.metadata
   :members:

.. automodule:: pyngb.extractors.streams
   :members:

Constants
~~~~~~~~~

.. automodule:: pyngb.constants
   :members:

Exceptions
~~~~~~~~~~

.. automodule:: pyngb.exceptions
   :members:

Utilities
~~~~~~~~~

.. automodule:: pyngb.util
   :members:
